import React, { useCallback, useContext, useEffect, useState } from 'react';
import { CloseBtn } from '../../CloseBtn';
import { Modal } from '../../Modal';
import { ScreenMedia } from '../../ScreenMedia';
import { PageListingContext } from '../PageListingContext';
import { IFiltersComponentProps, IFiltersContainerProps } from './FiltersContainer.interface';
import * as S from './FiltersContainer.style';

export const FiltersContainer: React.FunctionComponent<IFiltersContainerProps> = function FiltersComponent(
   props,
): JSX.Element {
   const pageListing = useContext(PageListingContext);

   return (
      <S.FiltersContainerStyle>
         <FiltersDesktop
            FiltersComponent={props.filterComponent}
            handleFilters={pageListing.updateFilters}
            clearFilters={pageListing.clearFilters}
            filters={pageListing.filters}
         />
         <FiltersMobile
            FiltersComponent={props.filterComponent}
            handleFilters={pageListing.updateFiltersDebounce}
            filters={pageListing.filters}
            filterMobileOpen={pageListing.filterMobileOpen}
            clean={props.useClean}
            clearFilters={pageListing.clearFilters}
            closeFilters={pageListing.closeFilters}
            applyFilters={pageListing.applyFiltersDebounce}
         />
      </S.FiltersContainerStyle>
   );
};

const FiltersDesktop = function FiltersDesktop(props: any): JSX.Element {
   const { FiltersComponent } = props;

   return (
      <ScreenMedia showIn="desktop">
         <div className="filters">
            <div className="filters-content" data-cy="desktop-filters">
               <FiltersComponent handleFilters={props.handleFilters} filters={props.filters} />
            </div>
         </div>
      </ScreenMedia>
   );
};

function FiltersMobile({
   filterMobileOpen,
   FiltersComponent,
   handleFilters,
   filters,
   clearFilters,
   closeFilters,
   applyFilters,
   clean = true,
}): JSX.Element {
   return (
      <ScreenMedia size="mobile">
         <Modal show={filterMobileOpen} animation="slideDown">
            <S.FiltersMobileStyle>
               {!clean && (
                  <>
                     <div className="filters-title">
                        Filtrar
                        <div
                           className="clear-filters text-primary"
                           onClick={clearFilters}
                           data-cy="clear-mobile-filters"
                        >
                           LIMPAR FILTROS
                        </div>
                        <div className="close-btn" onClick={closeFilters}>
                           <CloseBtn />
                        </div>
                     </div>

                     <div className="filters-body">
                        <FiltersComponent handleFilters={handleFilters} filters={filters} />
                     </div>

                     <div className="filters-btn" data-cy="btn-mobile-filters">
                        <button className="btn btn-primary" onClick={applyFilters} type="button">
                           Filtrar
                        </button>
                     </div>
                  </>
               )}
               {clean && <FiltersComponent handleFilters={handleFilters} filters={filters} />}
            </S.FiltersMobileStyle>
         </Modal>
      </ScreenMedia>
   );
}
