import React, { useRef, useEffect, useImperativeHandle } from 'react';
import { useField } from '@unform/core';
import { IUnformInputProps, IUnformInputRef } from './UnformInput.interface';

export const UnformInput = React.forwardRef<IUnformInputRef, IUnformInputProps>(function UnformInput(
   props,
   inputRef: any,
) {
   const { fieldName, registerField, defaultValue = null } = useField(props.name);

   const ref = useRef<any>({
      value: defaultValue ?? null,
   });
   useImperativeHandle(inputRef, () => ref.current, []);

   useEffect(() => {
      if (props.value !== undefined) {
         ref.current.value = props.value;
      }
   }, [props.value]);

   useEffect(() => {
      registerField({
         name: fieldName,
         ref,
         path: 'current' as any,
         clearValue(_ref) {
            ref.current.value = null;
         },
         setValue(_ref: any, value: string) {
            ref.current.value = value;
         },
         getValue(_ref: any) {
            return ref.current.value;
         },
      });
   }, [fieldName, registerField]);

   return null;
});
